.k_en_algo_admm_lin <- 1L
.k_en_algo_admm_var <- 2L
.k_en_algo_dal <- 3L
.k_en_algo_augridge <- 4L
.k_en_algo_lars <- 5L
.k_en_algo_cdls <- 6L

.k_pense_algo_mm <- 1L
.k_pense_algo_admm <- 2L
.k_pense_algo_cd <- 3L

.k_regm_algo_mm <- 1L

.k_rho_function_huber <- 1L
.k_rho_function_bisquare <- 2L
.k_rho_function_opt <- 3L
